@@ -22,7 +22,7 @@ from .base.fields import ArrayField
 
 try:
     import shapely
-    from shapely.geometry import asLineString, asPolygon, Point, Polygon
+    from shapely.geometry import LineString, Point, Polygon
 except ImportError:
     shapely = None
 
@@ -44,12 +44,10 @@ class GeomArrayField(ArrayField):
     def get_mask_by_geometry(self, geometry, values):
         geoms = self._to_shapely_geom(values)
 
-        selected_geoms = select_geoms_by_geometry(geoms, geometry)
+        intersects_i = select_geoms_by_geometry(geoms, geometry)
 
         mask = np.zeros((len(values.T),), dtype=bool)
-        for geom in selected_geoms:
-            mask[geom.index] = True
-
+        mask[np.array(intersects_i, dtype=int)] = True
         return mask
 
     def _to_shapely_geom(self, values):
@@ -102,13 +100,13 @@ class PointArrayField(GeomArrayField):
             raise_import_exception("shapely")
 
         points = []
-        for i, coord in enumerate(values.T):
+        for coord in values.T:
             if np.isnan(coord).all():
                 coord = np.full_like(coord, fill_value=NULL_VALUE)
 
             point = Point(coord[0], coord[1])
-            point.index = i  # the index is used in get_mask_by_geometry
             points.append(point)
+
         return points
 
 
@@ -189,11 +187,10 @@ class LineArrayField(GeomArrayField):
             raise_import_exception("shapely")
 
         lines = []
-        for i, coords in enumerate(values.T):
+        for coords in values.T:
             if np.isnan(coords).all():
                 coords = np.full_like(coords, fill_value=NULL_VALUE)
-            line = asLineString(coords.reshape((2, -1)))
-            line.index = i  # the index is used in get_mask_by_geometry
+            line = LineString(coords.reshape((2, -1)))
             lines.append(line)
         return lines
 
@@ -222,12 +219,11 @@ class MultiLineArrayField(GeomArrayField):
             raise_import_exception("shapely")
 
         multilines = []
-        for i, coords in enumerate(values):
+        for coords in values:
             if np.isnan(coords).all():
                 coords = np.full_like(coords, fill_value=NULL_VALUE)
 
-            line = asLineString(coords.reshape((2, -1)).T)
-            line.index = i  # the index is used in get_mask_by_geometry
+            line = LineString(coords.reshape((2, -1)).T)
             multilines.append(line)
         return multilines
 
@@ -267,11 +263,10 @@ class PolygonArrayField(GeomArrayField):
             raise_import_exception("shapely")
 
         polygons = []
-        for i, coords in enumerate(values):
+        for coords in values:
             if np.isnan(coords).all():
                 coords = np.full_like(coords, fill_value=NULL_VALUE)
-            polygon = asPolygon(coords.reshape((2, -1)).T)
-            polygon.index = i  # the index is used in get_mask_by_geometry
+            polygon = Polygon(coords.reshape((2, -1)).T)
             polygons.append(polygon)
         return polygons
 
@@ -284,7 +279,7 @@ class BboxArrayField(LineArrayField):
             raise_import_exception("shapely")
 
         polygons = []
-        for i, coord in enumerate(values.T):
+        for coord in values.T:
             if np.isnan(coord).all():
                 coord = np.full_like(coord, fill_value=NULL_VALUE)
 
@@ -297,6 +292,5 @@ class BboxArrayField(LineArrayField):
                     (coord[2], coord[1]),
                 ]
             )
-            polygon.index = i  # the index is used in get_mask_by_geometry
             polygons.append(polygon)
         return polygons
